MTfit.convert
=============


.. literalinclude:: ../../src/MTfit/convert/moment_tensor_conversion.py

There are also Cython functions:

.. literalinclude:: ../../src/MTfit/convert/cmoment_tensor_conversion.pyx
    :end-before: # Test functions
    :language: cython